library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity MIDIParser is
	generic (
		CC1 : integer := 71;
		CC2 : integer := 74
	);
	port (
		Reset   : in std_logic;
		Clk     : in std_logic;
		RxIn    : in std_logic;
		TrigOut : out std_logic;
		IncOut  : out std_logic_vector(31 downto 0);
		VelOut  : out std_logic_vector(6 downto 0);
		CC1Out  : out std_logic_vector(6 downto 0);
		CC2Out  : out std_logic_vector(6 downto 0);
		CC3Out  : out std_logic_vector(6 downto 0)
	);
end entity;

architecture RTL of MIDIParser is
	component Stage1MIDIParser is
		generic (
			CC1 : integer := 71;
			CC2 : integer := 74
		);
		port (
			Reset     : in std_logic;
			Clk       : in std_logic;
			RxIn      : in std_logic;
			KeyOnOut  : out std_logic;
			KeyOffOut : out std_logic;
			KeyOut    : out std_logic_vector(6 downto 0);
			VelOut    : out std_logic_vector(6 downto 0);
			CC1Out    : out std_logic_vector(6 downto 0);
			CC2Out    : out std_logic_vector(6 downto 0);
			CC3Out    : out std_logic_vector(6 downto 0)
		);
	end component;
	component Stage2MIDIParser is
		port (
			Reset    : in std_logic;
			Clk      : in std_logic;
			KeyOnIn  : in std_logic;
			KeyOffIn : in std_logic;
			KeyIn    : in std_logic_vector(6 downto 0);
			VelIn    : in std_logic_vector(6 downto 0);
			TrigOut  : out std_logic;
			KeyOut   : out std_logic_vector(6 downto 0);
			VelOut   : out std_logic_vector(6 downto 0)
		);
	end component;
	component NotesRom is
		port (
			AddressIn : in std_logic_vector(6 downto 0);
			DataOut   : out std_logic_vector(31 downto 0)
		);
	end component;
	signal S1KeyOn : std_logic;
	signal S1KeyOff : std_logic;
	signal S1Key : std_logic_vector(6 downto 0);
	signal S1Vel : std_logic_vector(6 downto 0);
	signal S2Key : std_logic_vector(6 downto 0);
begin
	S1 : Stage1MIDIParser port map (
		Reset => Reset,
		Clk => Clk,
		RxIn => RxIn,
		KeyOnOut => S1KeyOn,
		KeyOffOut => S1KeyOff,
		KeyOut => S1Key,
		VelOut => S1Vel,
		CC1OUt => CC1Out,
		CC2Out => CC2Out,
		CC3Out => CC3Out
	);
	S2 : Stage2MIDIParser port map (
		Reset => Reset,
		Clk => Clk,
		KeyOnIn => S1KeyOn,
		KeyOffIn => S1KeyOff,
		KeyIn => S1Key,
		VelIn => S1Vel,
		TrigOut => TrigOut,
		KeyOut => S2Key,
		VelOut => VelOut
	);
	NR : NotesRom port map (
		AddressIn => S2Key,
		DataOut => IncOut
	);
end architecture;
