library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity NotesRom is
	port (
		AddressIn : in std_logic_vector(6 downto 0);
		DataOut   : out std_logic_vector(31 downto 0)
	);
end entity;

architecture RTL of NotesRom is
	type RomType is array (0 to 127) of std_logic_vector(31 downto 0);
	constant Data : RomType := (
		x"00000000",   -- note 0
		x"000cdf51",   -- note 1
		x"000da345",   -- note 2
		x"000e72df",   -- note 3
		x"000f4ed1",   -- note 4
		x"001037d7",   -- note 5
		x"00112eb9",   -- note 6
		x"00123449",   -- note 7
		x"00134966",   -- note 8
		x"00146efe",   -- note 9
		x"0015a60b",   -- note 10
		x"0016ef97",   -- note 11
		x"00184cbb",   -- note 12
		x"0019bea3",   -- note 13
		x"001b4689",   -- note 14
		x"001ce5bd",   -- note 15
		x"001e9da2",   -- note 16
		x"00206fae",   -- note 17
		x"00225d72",   -- note 18
		x"00246891",   -- note 19
		x"002692cc",   -- note 20
		x"0028ddfc",   -- note 21
		x"002b4c16",   -- note 22
		x"002ddf2e",   -- note 23
		x"00309977",   -- note 24
		x"00337d46",   -- note 25
		x"00368d12",   -- note 26
		x"0039cb7a",   -- note 27
		x"003d3b43",   -- note 28
		x"0040df5d",   -- note 29
		x"0044bae3",   -- note 30
		x"0048d122",   -- note 31
		x"004d2598",   -- note 32
		x"0051bbf7",   -- note 33
		x"0056982b",   -- note 34
		x"005bbe5b",   -- note 35
		x"006132ee",   -- note 36
		x"0066fa8b",   -- note 37
		x"006d1a25",   -- note 38
		x"007396f5",   -- note 39
		x"007a7687",   -- note 40
		x"0081beba",   -- note 41
		x"008975c6",   -- note 42
		x"0091a245",   -- note 43
		x"009a4b30",   -- note 44
		x"00a377ee",   -- note 45
		x"00ad3057",   -- note 46
		x"00b77cb7",   -- note 47
		x"00c265db",   -- note 48
		x"00cdf517",   -- note 49
		x"00da3449",   -- note 50
		x"00e72de9",   -- note 51
		x"00f4ed0d",   -- note 52
		x"01037d73",   -- note 53
		x"0112eb8d",   -- note 54
		x"01234489",   -- note 55
		x"01349660",   -- note 56
		x"0146efdd",   -- note 57
		x"015a60ad",   -- note 58
		x"016ef96e",   -- note 59
		x"0184cbb7",   -- note 60
		x"019bea2e",   -- note 61
		x"01b46893",   -- note 62
		x"01ce5bd3",   -- note 63
		x"01e9da1a",   -- note 64
		x"0206fae6",   -- note 65
		x"0225d71a",   -- note 66
		x"02468913",   -- note 67
		x"02692cc0",   -- note 68
		x"028ddfb9",   -- note 69
		x"02b4c15b",   -- note 70
		x"02ddf2dc",   -- note 71
		x"0309976e",   -- note 72
		x"0337d45b",   -- note 73
		x"0368d125",   -- note 74
		x"039cb7a6",   -- note 75
		x"03d3b434",   -- note 76
		x"040df5cd",   -- note 77
		x"044bae34",   -- note 78
		x"048d1225",   -- note 79
		x"04d2597f",   -- note 80
		x"051bbf73",   -- note 81
		x"056982b5",   -- note 82
		x"05bbe5b7",   -- note 83
		x"06132edc",   -- note 84
		x"066fa8b7",   -- note 85
		x"06d1a24a",   -- note 86
		x"07396f4b",   -- note 87
		x"07a76869",   -- note 88
		x"081beb99",   -- note 89
		x"08975c67",   -- note 90
		x"091a244a",   -- note 91
		x"09a4b2ff",   -- note 92
		x"0a377ee6",   -- note 93
		x"0ad3056b",   -- note 94
		x"0b77cb6e",   -- note 95
		x"0c265db8",   -- note 96
		x"0cdf516e",   -- note 97
		x"0da34494",   -- note 98
		x"0e72de96",   -- note 99
		x"0f4ed0d2",   -- note 100
		x"1037d732",   -- note 101
		x"112eb8cf",   -- note 102
		x"12344895",   -- note 103
		x"134965fd",   -- note 104
		x"146efdcb",   -- note 105
		x"15a60ad5",   -- note 106
		x"16ef96dd",   -- note 107
		x"184cbb70",   -- note 108
		x"19bea2db",   -- note 109
		x"1b468929",   -- note 110
		x"1ce5bd2c",   -- note 111
		x"1e9da1a4",   -- note 112
		x"206fae65",   -- note 113
		x"225d719d",   -- note 114
		x"24689129",   -- note 115
		x"2692cbfb",   -- note 116
		x"28ddfb97",   -- note 117
		x"2b4c15ab",   -- note 118
		x"2ddf2db9",   -- note 119
		x"309976df",   -- note 120
		x"337d45b6",   -- note 121
		x"368d1251",   -- note 122
		x"39cb7a59",   -- note 123
		x"3d3b4348",   -- note 124
		x"40df5cc9",   -- note 125
		x"44bae33a",   -- note 126
		x"48d12253"    -- note 127
	);
begin
	DataOut <= Data(to_integer(unsigned(AddressIn)));
end architecture;
