library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity Oscillator is
	port (
		Clk       : in std_logic;
		Reset     : in std_logic;
		EnableIn  : in std_logic;
		IncIn     : in std_logic_vector(31 downto 0);
		SampleOut : out std_logic_vector(15 downto 0);
		EnableOut : out std_logic
    );
end entity;

architecture RTL of Oscillator is
	signal EnableDBus : std_logic;
	signal EnableQBus : std_logic;
	signal OscDBus : std_logic_vector(31 downto 0);
	signal OscQBus : std_logic_vector(31 downto 0);
	-- inc = (tone_freq * 65536) / sampling_freq
	-- inc = (440 * 65536) / ( (32000000 / 35) / 32 ) = 1009.2544
	--constant INC : integer := 66142496;   -- 1009.2544 in Q16.16 fixed point format
	constant INC : integer := 16535624;
begin
	-- oscillator
	process (Clk)
	begin
		if (Clk'event and (Clk = '1')) then
			OscQBus <= OscDBus;
		end if;
	end process;

	OscDBus <= std_logic_vector(to_signed(0, 32)) when (Reset = '1') else
	           std_logic_vector(to_signed(to_integer(signed(OscQBus)) + to_integer(unsigned(IncIn)), 32)) when (EnableIn = '1') else
	           OscQBus;
	SampleOut <= OscQBus(31 downto 16);

	process (Clk)
	begin
		if (Clk'event and (Clk = '1')) then
			EnableQBus <= EnableDBus;
		end if;
	end process;

	EnableDBus <= EnableIn;
	EnableOut <= EnableQBus;
end architecture;
