library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity Stage2MIDIParser is
	port (
		Reset    : in std_logic;
		Clk      : in std_logic;
		KeyOnIn  : in std_logic;
		KeyOffIn : in std_logic;
		KeyIn    : in std_logic_vector(6 downto 0);
		VelIn    : in std_logic_vector(6 downto 0);
		TrigOut  : out std_logic;
		KeyOut   : out std_logic_vector(6 downto 0);
		VelOut   : out std_logic_vector(6 downto 0)
	);
end entity;

architecture RTL of Stage2MIDIParser is
	signal KeyDBus : std_logic_vector(6 downto 0);
	signal KeyQBus : std_logic_vector(6 downto 0);
	signal VelDBus : std_logic_vector(6 downto 0);
	signal VelQBus : std_logic_vector(6 downto 0);
	signal FSMDBus : std_logic_vector(1 downto 0);
	signal FSMQBus : std_logic_vector(1 downto 0);
begin
	process (Clk)
	begin
		if (Clk'event and (Clk = '1')) then
			FSMQBus <= FSMDBus;
		end if;
	end process;

	FSMDBus <= "00" when ((Reset = '1') or ((FSMQBus = "10") and (KeyOffIn = '1') and (KeyIn = KeyQBus))) else
	           "01" when (((FSMQBus = "00") and (KeyOnIn = '1')) or (FSMQBus = "11")) else
	           "10" when (FSMQBus = "01") else
	           "11" when ((FSMQBus = "10") and (KeyOnIn = '1')) else
	           FSMQBus;

	process (Clk)
	begin
		if (Clk'event and (Clk = '1')) then
			KeyQBus <= KeyDBus;
		end if;
	end process;

	KeyDBus <= KeyIn when (FSMQBus = "01") else
	           KeyQBus;
	KeyOut <= KeyQBus;

	process (Clk)
	begin
		if (Clk'event and (Clk = '1')) then
			VelQBus <= VelDBus;
		end if;
	end process;

	VelDBus <= VelIn when (FSMQBus = "01") else
	           VelQBus;

	TrigOut <= '1' when (FSMQBus = "10") else
	           '0';
end architecture;
